@@ -11,7 +11,7 @@ find(sub {
 	   my $name = $File::Find::name;
 	   # Assumes that the path separator is exactly one character.
 	   $name =~ s/^\.\..//;
-	   push @{$files{lc $name}}, $name;
+	   push @{%files{lc $name}}, $name;
 	 }, '.');
 
 my $failed;
