@@ -30,13 +30,13 @@ sub ch_index ()
 
 my %dep = (
     # This symbol must be defined BEFORE ...
-    BYTEORDER		=> [ qw( UVSIZE				) ],
-    LONGSIZE		=> [ qw( BYTEORDER			) ],
-    MULTIARCH		=> [ qw( BYTEORDER MEM_ALIGNBYTES	) ],
-    USE_CROSS_COMPILE	=> [ qw( BYTEORDER MEM_ALIGNBYTES	) ],
-    HAS_QUAD		=> [ qw( I64TYPE			) ],
-    HAS_GETGROUPS	=> [ qw( Groups_t			) ],
-    HAS_SETGROUPS	=> [ qw( Groups_t			) ],
+    BYTEORDER		=> \@( qw( UVSIZE				) ),
+    LONGSIZE		=> \@( qw( BYTEORDER			) ),
+    MULTIARCH		=> \@( qw( BYTEORDER MEM_ALIGNBYTES	) ),
+    USE_CROSS_COMPILE	=> \@( qw( BYTEORDER MEM_ALIGNBYTES	) ),
+    HAS_QUAD		=> \@( qw( I64TYPE			) ),
+    HAS_GETGROUPS	=> \@( qw( Groups_t			) ),
+    HAS_SETGROUPS	=> \@( qw( Groups_t			) ),
     );
 
 my $changed;
