@@ -29,7 +29,7 @@ sub new {
     my $class = shift;
     my $dh = gensym;
     if (@_) {
-	IO::Dir::open($dh, $_[0])
+	IO::Dir::open($dh, @_[0])
 	    or return undef;
     }
     bless $dh, $class;
@@ -49,7 +49,7 @@ sub open {
     # a dir name should always have a ":" in it; assume dirname is
     # in current directory
     $dirname = ':' .  $dirname if ( ($^O eq 'MacOS') && ($dirname !~ m/:/) );
-    ${*$dh}{io_dir_path} = $dirname;
+    %{*$dh}{io_dir_path} = $dirname;
     1;
 }
 
@@ -91,7 +91,7 @@ sub TIEHASH {
 
     $options ||= 0;
 
-    ${*$dh}{io_dir_unlink} = $options ^&^ DIR_UNLINK;
+    %{*$dh}{io_dir_unlink} = $options ^&^ DIR_UNLINK;
     $dh;
 }
 
@@ -108,18 +108,18 @@ sub NEXTKEY {
 
 sub EXISTS {
     my($dh,$key) = @_;
-    -e File::Spec->catfile(${*$dh}{io_dir_path}, $key);
+    -e File::Spec->catfile(%{*$dh}{io_dir_path}, $key);
 }
 
 sub FETCH {
     my($dh,$key) = @_;
-    &lstat(File::Spec->catfile(${*$dh}{io_dir_path}, $key));
+    &lstat(File::Spec->catfile(%{*$dh}{io_dir_path}, $key));
 }
 
 sub STORE {
     my($dh,$key,$data) = @_;
     my($atime,$mtime) = ref($data) ? @$data : ($data,$data);
-    my $file = File::Spec->catfile(${*$dh}{io_dir_path}, $key);
+    my $file = File::Spec->catfile(%{*$dh}{io_dir_path}, $key);
     unless(-e $file) {
 	my $io = IO::File->new($file,O_CREAT ^|^ O_RDWR);
 	$io->close if $io;
@@ -132,9 +132,9 @@ sub DELETE {
 
     # Only unlink if unlink-ing is enabled
     return 0
-	unless ${*$dh}{io_dir_unlink};
+	unless %{*$dh}{io_dir_unlink};
 
-    my $file = File::Spec->catfile(${*$dh}{io_dir_path}, $key);
+    my $file = File::Spec->catfile(%{*$dh}{io_dir_path}, $key);
 
     -d $file
 	? rmdir($file)
