@@ -17,13 +17,13 @@ sub mkUncompObject
     my $crc32 = 1; #shift ;
     my $adler32 = shift;
 
-    bless { 'CompSize'   => 0,
+    bless \%( 'CompSize'   => 0,
             'UnCompSize' => 0,
             'wantCRC32'  => $crc32,
             'CRC32'      => Compress::Raw::Zlib::crc32(''),
             'wantADLER32'=> $adler32,
             'ADLER32'    => Compress::Raw::Zlib::adler32(''),
-          } ;
+          ) ;
 }
 
 sub uncompr
