@@ -1,7 +1,7 @@
 use Perl6::Form;
 
 
-print form {interleave=>1,,single=>'^'},{single=>'='},{single=>'_'},
+print form \%(interleave=>1,,single=>'^'),\%(single=>'='),\%(single=>'_'),
 		   <<'.',
 ~~~~~~~~~
 ^ = ^ _ ^ {|||}
@@ -11,13 +11,13 @@ print form {interleave=>1,,single=>'^'},{single=>'='},{single=>'_'},
 
 print "\n--------------------------\n\n";
 
-print form {single=>'='}, {interleave=>1}, <<'.',
+print form \%(single=>'='), \%(interleave=>1), <<'.',
    ^
  = | {""""""""""""""""""""""""""""""""""""}
    +--------------------------------------->
     {|||||||||||||||||||||||||||||||||||}
 .
- "Height", [ ~< *DATA], "Time";
+ "Height", \@( ~< *DATA), "Time";
 
 
 print form <<'.',
@@ -26,16 +26,16 @@ Passed:
 Failed:
 	{[[[[[[[[[[[[[[[[[[[}
 .
-[qw(Smith Simmons Sutton Smee)], [qw(Richards Royce Raighley)];
+\@(qw(Smith Simmons Sutton Smee)), \@(qw(Richards Royce Raighley));
 
 
-print form {interleave=>1}, <<'.',
+print form \%(interleave=>1), <<'.',
 Passed:
 	{[[[[[[[[[[[[[[[[[[[}
 Failed:
 	{[[[[[[[[[[[[[[[[[[[}
 .
-[qw(Smith Simmons Sutton Smee)], [qw(Richards Royce Raighley)];
+\@(qw(Smith Simmons Sutton Smee)), \@(qw(Richards Royce Raighley));
 
 __DATA__
       *
