@@ -7,7 +7,7 @@ s/\\n/\n/g for @items;
 s/\\r/\r/g for @items;
 
 print form
-	{bullet=>'<>'},
+	\%(bullet=>'<>'),
 	 "<> \{:[[[[[[[[[[[[[[[[[[:\}    <> \{:[[[[[[[[[[[[[[[[[[:\}",
 		 \@items,                     \@items;
 
@@ -15,7 +15,7 @@ my $items = join "", @items;
 
 print form
 	 "-----------------------",
-     {bullet=>'<>'},
+     \%(bullet=>'<>'),
 	 "<> \{:[[[[[[[[[[[[[[[[[[:\}    <> \{:[[[[[[[[[[[[[[[[[[:\}",
 		 $items,                      $items;
 
