@@ -1,7 +1,7 @@
 use Perl6::Form;
 
 print form
-	{page=>{length=>4, header=>'=========='}},
+	\%(page=>\%(length=>4, header=>'==========')),
 	"\{>>>>>>>>\} \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}",
      "foo bar baz qux",
                 "foo bar baz qux" x 30,
