@@ -19,7 +19,7 @@ print form
      "_____________",
      "\{] ]]] ]]]|[\}",
      "$nums",
-	 {locale=>1},
+	 \%(locale=>1),
 	 "",
 	 "Locale ",
      "_____________",
