@@ -5,19 +5,19 @@ my @text = ~< *DATA;
 my @title = ("Hamlet's Soliloquy","W. Shakespeare");
 
 my %header = (
-	first => sub { form({ page => {width=>@_[0]{page}{width}}},
+	first => sub { form(\%( page => \%(width=>@_[0]{page}{width})),
 				        "\{II\{*\}II\}", \@title) . "\n";
 				 },
-	  odd => sub { form({ page => {width=>@_[0]{page}{width}}},
+	  odd => sub { form(\%( page => \%(width=>@_[0]{page}{width})),
 				        "\{]]\{*\}]]\}", @title[0]) . "\n";
 				 },
-	 even => sub { form({ page => {width=>@_[0]{page}{width}}},
+	 even => sub { form(\%( page => \%(width=>@_[0]{page}{width})),
 				        "\{[[\{*\}[[\}", @title[1]) . "\n";
 				 },
 );
 
 sub footer {
-	form { page => {width=>@_[0]{page}{width}} },
+	form \%( page => \%(width=>@_[0]{page}{width}) ),
 		 "\n\{|\{*\}|\}",
 		 "(page @_[0]{page}{number})"
 }
@@ -30,9 +30,9 @@ my %page = (
 	feed   => ('_'x72)."\n",
 );
 
-print form {page=>\%page},
+print form \%(page=>\%page),
 	 '{]]]]]}  {"{*}"}  {[[[[[}',
-	 [1..@text], \@text,  [1..@text];
+	 \@(1..@text), \@text,  \@(1..@text);
 
 __DATA__
 To be, or not to be -- that is the question:
