@@ -5,13 +5,13 @@ $x = "the    firstest    field    is    here and         there";
 $y = "     the second field is here";
 @z = qw(heyah hey heyah hey heyah hey);
 
-print form {out=>\*STDERR, single=>"=", ws=>qr/[^\S\n]+/,
+print form \%(out=>\*STDERR, single=>"=", ws=>qr/[^\S\n]+/,
 	  # layout=>'across'
-	 },
+	 ),
       "= hi [\{:[[[[:\}] there [\{:>>\}] you \{:III:\}\{]][[\} -> \{]]].[[\}",
       'demo',
-			 $x,              {bfill=>'*  '}, 
-							  $y,        {bfill=>'+'},
-										 $x,    \@z,       {rfill=>0}, $w;
+			 $x,              \%(bfill=>'*  '), 
+							  $y,        \%(bfill=>'+'),
+										 $x,    \@z,       \%(rfill=>0), $w;
 
 print "\n\n", substr($y, pos$y), "\n";
