@@ -1,6 +1,6 @@
 use Perl6::Form;
 
-print form {single=>'^'},{single=>'='},{single=>'_'},
+print form \%(single=>'^'),\%(single=>'='),\%(single=>'_'),
 		   '~~~~~~~~~',
 		   '^ _ = _ ^',
 		   qw(Like round and orient perls),
@@ -8,11 +8,11 @@ print form {single=>'^'},{single=>'='},{single=>'_'},
 
 print "\n--------------------------\n\n";
 
-print form {single=>'='},
+print form \%(single=>'='),
            '   ^',
            ' = | {""""""""""""""""""""""""""""""""""""}',
 			 "Height",
-				 [ ~< *DATA],
+				 \@( ~< *DATA),
 		   '   +------------------------------------->',
 		   '    {|||||||||||||||||||||||||||||||||||}',
 				"Time";
