@@ -50,7 +50,7 @@ Time::HiRes->bootstrap();
 sub tv_interval {
     # probably could have been done in C
     my ($a, $b) = @_;
-    $b = [gettimeofday()] unless defined($b);
+    $b = \@(gettimeofday()) unless defined($b);
     (@{$b}[0] - @{$a}[0]) + ((@{$b}[1] - @{$a}[1]) / 1_000_000);
 }
 
