@@ -36,7 +36,7 @@ sub setcolor {
  eval {				# Ignore errors
   require Term::Cap;
 
-  my $terminal = Term::Cap->Tgetent({OSPEED => 9600}); # Avoid warning.
+  my $terminal = Term::Cap->Tgetent(\%(OSPEED => 9600)); # Avoid warning.
   my $props = %ENV{PERL_RE_TC} || 'md,me,so,se,us,ue';
   my @props = split m/,/, $props;
   my $colors = join "\t", map {$terminal->Tputs($_,1)} @props;
