@@ -122,7 +122,7 @@ sub format_arg {
 sub get_status {
     my $cache = shift;
     my $pkg = shift;
-    $cache->{$pkg} ||= [{$pkg => $pkg}, [trusts_directly($pkg)]];
+    $cache->{$pkg} ||= \@(\%($pkg => $pkg), \@(trusts_directly($pkg)));
     return @{$cache->{$pkg}};
 }
 
@@ -221,7 +221,7 @@ sub short_error_loc {
   # You have to create your (hash)ref out here, rather than defaulting it
   # inside trusts *on a lexical*, as you want it to persist across calls.
   # (You can default it on $_[2], but that gets messy)
-  my $cache = {};
+  my $cache = \%();
   my $i = 1;
   my $lvl = $CarpLevel;
   {
