@@ -49,14 +49,14 @@ sub C_stringify {
   s/\f/\\f/g;
   s/\a/\\a/g;
   if (ord('A') == 193) { # EBCDIC has no ^\0-\177 workalike.
-      s/([[:^print:]])/{sprintf "\\%03o", ord $1}/g;
+      s/([[:^print:]])/{sprintf "\\\%03o", ord $1}/g;
   } else {
-      s/([^\0-\177])/{sprintf "\\%03o", ord $1}/g;
+      s/([^\0-\177])/{sprintf "\\\%03o", ord $1}/g;
   }
     # This will elicit a warning on 5.005_03 about [: :] being reserved unless
     # I cheat
     my $cheat = '([[:^print:]])';
-    s/$cheat/{sprintf "\\%03o", ord $1}/g;
+    s/$cheat/{sprintf "\\\%03o", ord $1}/g;
   $_;
 }
 
@@ -78,11 +78,11 @@ sub perl_stringify {
   s/\t/\\t/g;
   s/\f/\\f/g;
   s/\a/\\a/g;
-  s/([^\0-\177])/{sprintf "\\x\{%X\}", ord $1}/g;
+  s/([^\0-\177])/{sprintf "\\x\{\%X\}", ord $1}/g;
   # This will elicit a warning on 5.005_03 about [: :] being reserved unless
   # I cheat
   my $cheat = '([[:^print:]])';
-  s/$cheat/{sprintf "\\%03o", ord $1}/g;
+  s/$cheat/{sprintf "\\\%03o", ord $1}/g;
   $_;
 }
 
