@@ -29,7 +29,7 @@ $VERSION = '1.26_01';
 #*canon = \&ExtUtils::Miniperl::canon;
 
 $Verbose = 0;
-$lib_ext = $Config{lib_ext} || '.a';
+$lib_ext = %Config{lib_ext} || '.a';
 
 sub is_cmd { $0 eq '-e' }
 
@@ -68,7 +68,7 @@ sub xsinit {
     }
 
     push(@mods, static_ext()) if defined $std;
-    @mods = grep(!$seen{$_}++, @mods);
+    @mods = grep(!%seen{$_}++, @mods);
 
     print $fh &xsi_header();
     print $fh "EXTERN_C void xs_init ($xsinit_proto);\n\n";     
@@ -97,8 +97,8 @@ sub xsi_protos {
         my($mname, $cname);
         ($mname = $pname) =~ s!/!::!g;
         ($cname = $pname) =~ s!/!__!g;
-	my($ccode) = "EXTERN_C void boot_${cname} ($boot_proto);\n";
-	next if $seen{$ccode}++;
+	my($ccode) = "EXTERN_C void boot_{$cname} ($boot_proto);\n";
+	next if %seen{$ccode}++;
         push(@retval, $ccode);
     }
     return join '', @retval;
@@ -120,11 +120,11 @@ sub xsi_body {
         if ($pname eq $dl){
             # Must NOT install 'DynaLoader::boot_DynaLoader' as 'bootstrap'!
             # boot_DynaLoader is called directly in DynaLoader.pm
-            $ccode = "\t/* DynaLoader is a special case */\n\tnewXS(\"${mname}::boot_${cname}\", boot_${cname}, file);\n";
-            push(@retval, $ccode) unless $seen{$ccode}++;
+            $ccode = "\t/* DynaLoader is a special case */\n\tnewXS(\"{$mname}::boot_{$cname}\", boot_{$cname}, file);\n";
+            push(@retval, $ccode) unless %seen{$ccode}++;
         } else {
-            $ccode = "\tnewXS(\"${mname}::bootstrap\", boot_${cname}, file);\n";
-            push(@retval, $ccode) unless $seen{$ccode}++;
+            $ccode = "\tnewXS(\"{$mname}::bootstrap\", boot_{$cname}, file);\n";
+            push(@retval, $ccode) unless %seen{$ccode}++;
         }
     }
     return join '', @retval;
@@ -132,7 +132,7 @@ sub xsi_body {
 
 sub static_ext {
     unless (scalar @Extensions) {
-      my $static_ext = $Config{static_ext};
+      my $static_ext = %Config{static_ext};
       $static_ext =~ s/^\s+//;
       @Extensions = sort split m/\s+/, $static_ext;
 	unshift @Extensions, qw(DynaLoader);
@@ -146,19 +146,19 @@ sub _escape {
 }
 
 sub _ldflags {
-    my $ldflags = $Config{ldflags};
+    my $ldflags = %Config{ldflags};
     _escape(\$ldflags);
     return $ldflags;
 }
 
 sub _ccflags {
-    my $ccflags = $Config{ccflags};
+    my $ccflags = %Config{ccflags};
     _escape(\$ccflags);
     return $ccflags;
 }
 
 sub _ccdlflags {
-    my $ccdlflags = $Config{ccdlflags};
+    my $ccdlflags = %Config{ccdlflags};
     _escape(\$ccdlflags);
     return $ccdlflags;
 }
@@ -185,13 +185,13 @@ sub ldopts {
        }
     }
     $std = 1 unless scalar @link_args;
-    my $sep = $Config{path_sep} || ':';
+    my $sep = %Config{path_sep} || ':';
     @path = $path ? split(m/\Q$sep/, $path) : @INC;
 
     push(@potential_libs, @link_args)    if scalar @link_args;
     # makemaker includes std libs on windows by default
     if ($^O ne 'MSWin32' and defined($std)) {
-	push(@potential_libs, $Config{perllibs});
+	push(@potential_libs, %Config{perllibs});
     }
 
     push(@mods, static_ext()) if $std;
@@ -200,10 +200,10 @@ sub ldopts {
     print STDERR "Searching (@path) for archives\n" if $Verbose;
     foreach $mod (@mods) {
 	@ns = split(m/::|\/|\\/, $mod);
-	$sub = $ns[-1];
+	$sub = @ns[-1];
 	$root = File::Spec->catdir(@ns);
 	
-	print STDERR "searching for '$sub${lib_ext}'\n" if $Verbose;
+	print STDERR "searching for '{$sub}{$lib_ext}'\n" if $Verbose;
 	foreach (@path) {
 	    next unless -e ($archive = File::Spec->catdir($_,"auto",$root,"$sub$lib_ext"));
 	    push @archives, $archive;
@@ -224,18 +224,18 @@ sub ldopts {
 
     my $libperl;
     if ($^O eq 'MSWin32') {
-	$libperl = $Config{libperl};
+	$libperl = %Config{libperl};
     }
-    elsif ($^O eq 'os390' && $Config{usedl}) {
+    elsif ($^O eq 'os390' && %Config{usedl}) {
 	# Nothing for OS/390 (z/OS) dynamic.
     } else {
-	$libperl = (grep(m/^-l\w*perl\w*$/, @link_args))[0]
-	    || ($Config{libperl} =~ m/^lib(\w+)(\Q$lib_ext\E|\.\Q$Config{dlext}\E)$/
+	$libperl = (grep(m/^-l\w*perl\w*$/, @link_args))[[0]]
+	    || (%Config{libperl} =~ m/^lib(\w+)(\Q$lib_ext\E|\.\Q%Config{dlext}\E)$/
 		? "-l$1" : '')
 		|| "-lperl";
     }
 
-    my $lpath = File::Spec->catdir($Config{archlibexp}, 'CORE');
+    my $lpath = File::Spec->catdir(%Config{archlibexp}, 'CORE');
     $lpath = qq["$lpath"] if $^O eq 'MSWin32';
     my($extralibs, $bsloadlibs, $ldloadlibs, $ld_run_path) =
 	MM->ext(join ' ', "-L$lpath", $libperl, @potential_libs);
@@ -262,7 +262,7 @@ sub ccdlflags {
 }
 
 sub perl_inc {
-    my $dir = File::Spec->catdir($Config{archlibexp}, 'CORE');
+    my $dir = File::Spec->catdir(%Config{archlibexp}, 'CORE');
     $dir = qq["$dir"] if $^O eq 'MSWin32';
     my_return(" -I$dir ");
 }
