@@ -16,8 +16,8 @@ sub ext {
 
 sub lsdir {
   shift;
-  my $rex = qr/$_[1]/;
-  opendir DIR, $_[0];
+  my $rex = qr/@_[1]/;
+  opendir DIR, @_[0];
   my @out = grep m/$rex/, readdir DIR;
   closedir DIR;
   return @out;
