@@ -38,9 +38,9 @@ sub dlsyms {
 
     return '' unless $self->needs_linking();
 
-    my($funcs) = %attribs{DL_FUNCS} || $self->{DL_FUNCS} || {};
-    my($vars)  = %attribs{DL_VARS} || $self->{DL_VARS} || [];
-    my($funclist)  = %attribs{FUNCLIST} || $self->{FUNCLIST} || [];
+    my($funcs) = %attribs{DL_FUNCS} || $self->{DL_FUNCS} || \%();
+    my($vars)  = %attribs{DL_VARS} || $self->{DL_VARS} || \@();
+    my($funclist)  = %attribs{FUNCLIST} || $self->{FUNCLIST} || \@();
     my(@m);
 
     push(@m,"
