@@ -49,7 +49,7 @@ sub init_linker {
     my($self) = shift;
 
     $self->{PERL_ARCHIVE} ||= 
-      File::Spec->catdir('$(PERL_INC)',$Config{libperl});
+      File::Spec->catdir('$(PERL_INC)',%Config{libperl});
     $self->{PERL_ARCHIVE_AFTER} ||= '';
     $self->{EXPORT_LIST}  ||= '';
 }
