@@ -19,10 +19,10 @@ sub Mksymlists {
         unless ( %spec{NAME} or
                  (%spec{FILE} and (%spec{DL_FUNCS} or %spec{FUNCLIST})) );
 
-    %spec{DL_VARS} = [] unless %spec{DL_VARS};
+    %spec{DL_VARS} = \@() unless %spec{DL_VARS};
     (%spec{FILE} = %spec{NAME}) =~ s/.*::// unless %spec{FILE};
-    %spec{FUNCLIST} = [] unless %spec{FUNCLIST};
-    %spec{DL_FUNCS} = { %spec{NAME} => [] }
+    %spec{FUNCLIST} = \@() unless %spec{FUNCLIST};
+    %spec{DL_FUNCS} = \%( %spec{NAME} => \@() )
         unless ( (%spec{DL_FUNCS} and keys %{%spec{DL_FUNCS}}) or
                  @{%spec{FUNCLIST}});
     if (defined %spec{DL_FUNCS}) {
@@ -46,7 +46,7 @@ sub Mksymlists {
 #    not as pseudo-builtin.
 #    require DynaLoader;
     if (defined &DynaLoader::mod2fname and not %spec{DLBASE}) {
-        %spec{DLBASE} = DynaLoader::mod2fname([ split(m/::/,%spec{NAME}) ]);
+        %spec{DLBASE} = DynaLoader::mod2fname(\@( split(m/::/,%spec{NAME}) ));
     }
 
     if    ($osname eq 'aix') { _write_aix(\%spec); }
