@@ -28,20 +28,20 @@ $VERSION        = eval $VERSION;    # avoid warnings with development releases
 $PREFER_BIN     = 0;                # XXX TODO implement
 $FROM_EMAIL     = 'File-Fetch@example.com';
 $USER_AGENT     = 'File::Fetch/$VERSION';
-$BLACKLIST      = [qw|ftp|];
-$METHOD_FAIL    = { };
+$BLACKLIST      = \@(qw|ftp|);
+$METHOD_FAIL    = \%( );
 $FTP_PASSIVE    = 1;
 $TIMEOUT        = 0;
 $DEBUG          = 0;
 $WARN           = 1;
 
 ### methods available to fetch the file depending on the scheme
-$METHODS = {
-    http    => [ qw|lwp wget curl lynx| ],
-    ftp     => [ qw|lwp netftp wget curl ncftp ftp| ],
-    file    => [ qw|lwp file| ],
-    rsync   => [ qw|rsync| ]
-};
+$METHODS = \%(
+    http    => \@( qw|lwp wget curl lynx| ),
+    ftp     => \@( qw|lwp netftp wget curl ncftp ftp| ),
+    file    => \@( qw|lwp file| ),
+    rsync   => \@( qw|rsync| )
+);
 
 ### silly warnings ###
 local $Params::Check::VERBOSE               = 1;
@@ -143,17 +143,17 @@ result of $ff->output_file will be used.
 
 {
     ### template for new() and autogenerated accessors ###
-    my $Tmpl = {
-        scheme          => { default => 'http' },
-        host            => { default => 'localhost' },
-        path            => { default => '/' },
-        file            => { required => 1 },
-        uri             => { required => 1 },
-        vol             => { default => '' }, # windows and vms for file:// uris
-        share           => { default => '' }, # windows for file:// uris
-        _error_msg      => { no_override => 1 },
-        _error_msg_long => { no_override => 1 },
-    };
+    my $Tmpl = \%(
+        scheme          => \%( default => 'http' ),
+        host            => \%( default => 'localhost' ),
+        path            => \%( default => '/' ),
+        file            => \%( required => 1 ),
+        uri             => \%( required => 1 ),
+        vol             => \%( default => '' ), # windows and vms for file:// uris
+        share           => \%( default => '' ), # windows for file:// uris
+        _error_msg      => \%( no_override => 1 ),
+        _error_msg_long => \%( no_override => 1 ),
+    );
     
     for my $method ( keys %$Tmpl ) {
         no strict 'refs';
@@ -263,9 +263,9 @@ sub new {
     my %hash  = @_;
 
     my ($uri);
-    my $tmpl = {
-        uri => { required => 1, store => \$uri },
-    };
+    my $tmpl = \%(
+        uri => \%( required => 1, store => \$uri ),
+    );
 
     check( $tmpl, \%hash ) or return;
 
@@ -323,7 +323,7 @@ sub _parse_uri {
     my $self = shift;
     my $uri  = shift or return;
 
-    my $href = { uri => $uri };
+    my $href = \%( uri => $uri );
 
     ### find the scheme ###
     $uri            =~ s|^(\w+)://||;
@@ -407,9 +407,9 @@ sub fetch {
     my %hash = @_;
 
     my $to;
-    my $tmpl = {
-        to  => { default => cwd(), store => \$to },
-    };
+    my $tmpl = \%(
+        to  => \%( default => cwd(), store => \$to ),
+    );
 
     check( $tmpl, \%hash ) or return;
 
@@ -488,20 +488,20 @@ sub _lwp_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### modules required to download with lwp ###
-    my $use_list = {
+    my $use_list = \%(
         LWP                 => '0.0',
         'LWP::UserAgent'    => '0.0',
         'HTTP::Request'     => '0.0',
         'HTTP::Status'      => '0.0',
         URI                 => '0.0',
 
-    };
+    );
 
     if( can_load(modules => $use_list) ) {
 
@@ -546,13 +546,13 @@ sub _netftp_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### required modules ###
-    my $use_list = { 'Net::FTP' => 0 };
+    my $use_list = \%( 'Net::FTP' => 0 );
 
     if( can_load( modules => $use_list ) ) {
 
@@ -600,16 +600,16 @@ sub _wget_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### see if we have a wget binary ###
     if( my $wget = can_run('wget') ) {
 
         ### no verboseness, thanks ###
-        my $cmd = [ $wget, '--quiet' ];
+        my $cmd = \@( $wget, '--quiet' );
 
         ### if a timeout is set, add it ###
         push(@$cmd, '--timeout=' . $TIMEOUT) if $TIMEOUT;
@@ -652,9 +652,9 @@ sub _ftp_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### see if we have a ftp binary ###
@@ -693,9 +693,9 @@ sub _lynx_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### see if we have a lynx binary ###
@@ -715,11 +715,11 @@ sub _lynx_fetch {
                             "Could not open '\%1' for writing: \%2",$to,$!));
 
         ### dump to stdout ###
-        my $cmd = [
+        my $cmd = \@(
             $lynx,
             '-source',
             "-auth=anonymous:$FROM_EMAIL",
-        ];
+        );
 
         push @$cmd, "-connect_timeout=$TIMEOUT" if $TIMEOUT;
 
@@ -763,9 +763,9 @@ sub _ncftp_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     ### we can only set passive mode in interactive sesssions, so bail out
@@ -775,7 +775,7 @@ sub _ncftp_fetch {
     ### see if we have a ncftp binary ###
     if( my $ncftp = can_run('ncftp') ) {
 
-        my $cmd = [
+        my $cmd = \@(
             $ncftp,
             '-V',                   # do not be verbose
             '-p', $FROM_EMAIL,      # email as password
@@ -788,7 +788,7 @@ sub _ncftp_fetch {
                         : QUOTE. File::Spec::Unix->catdir( 
                                         $self->path, $self->file ) .QUOTE
             
-        ];
+        );
 
         ### shell out ###
         my $captured;
@@ -813,15 +813,15 @@ sub _curl_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     if (my $curl = can_run('curl')) {
 
         ### these long opts are self explanatory - I like that -jmb
-	    my $cmd = [ $curl ];
+	    my $cmd = \@( $curl );
 
 	    push(@$cmd, '--connect-timeout', $TIMEOUT) if $TIMEOUT;
 
@@ -869,9 +869,9 @@ sub _file_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     
@@ -932,14 +932,14 @@ sub _rsync_fetch {
     my %hash = @_;
 
     my ($to);
-    my $tmpl = {
-        to  => { required => 1, store => \$to }
-    };
+    my $tmpl = \%(
+        to  => \%( required => 1, store => \$to )
+    );
     check( $tmpl, \%hash ) or return;
 
     if (my $rsync = can_run('rsync')) {
 
-        my $cmd = [ $rsync ];
+        my $cmd = \@( $rsync );
 
         ### XXX: rsync has no I/O timeouts at all, by default
         push(@$cmd, '--timeout=' . $TIMEOUT) if $TIMEOUT;
