@@ -129,10 +129,10 @@ while ( ~< *DATA) {
     s/#.*//;
     next unless $_;
     my($name, $type, $text) = split " ", $_, 3;
-    $Type{$name} = $type;
-    $Flavor{$name} = $text;
+    %Type{$name} = $type;
+    %Flavor{$name} = $text;
     for my $t ( split m/[,\s]+/, $type ) {
-        push @{$Kinds{$t}}, $name;
+        push @{%Kinds{$t}}, $name;
     }
 }
 
@@ -141,8 +141,8 @@ close DATA;
 my( $typedesc, $list );
 unless (caller) {
     foreach my $type ( @Type_Order ) {
-	$list = join(", ", sort @{$Kinds{$type}});
-	$typedesc = $Type_Description{$type} . ":";
+	$list = join(", ", sort @{%Kinds{$type}});
+	$typedesc = %Type_Description{$type} . ":";
 
         print form("",
                    "\{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}",
