@@ -125,7 +125,7 @@ sub initialize {
     %$self{sentence} = 0  unless defined %$self{sentence};
     %$self{width}    = 76 unless defined %$self{width};
 
-    %$self{INDENTS}  = [];              # Stack of indentations.
+    %$self{INDENTS}  = \@();              # Stack of indentations.
     %$self{MARGIN}   = %$self{indent};  # Current left margin in spaces.
 
     $self->SUPER::initialize;
