@@ -23,8 +23,8 @@ sub textblock {
     my($parser,$text,$line) = @_;
     print {$parser->output_handle()}
 	$parser->parse_text(
-	    { -expand_text => q(escape_ltgt),
-	      -expand_seq => q(simple_delimiters) },
+	    \%( -expand_text => q(escape_ltgt),
+	      -expand_seq => q(simple_delimiters) ),
 	    $text, $line ) -> raw_text(); 
 }
 
