@@ -14,7 +14,7 @@ use overload( # So it'll stringify nice
 );
 
 sub tack_on {
-  @_[0] = ['', {}, "@_[0]" ];
+  @_[0] = \@('', \%(), "@_[0]" );
   return @_[0][2] .= @_[1];
 }
 
@@ -31,14 +31,14 @@ sub new {
   my $new;
   if(@_ == 1) {
     if (!ref(@_[0] || '')) { # most common case: one bare string
-      return bless ['', {}, @_[0] ], $class;
+      return bless \@('', \%(), @_[0] ), $class;
     } elsif( ref(@_[0] || '') eq 'ARRAY') {
-      $new = [ @{ @_[0] } ];
+      $new = \@( @{ @_[0] } );
     } else {
       Carp::croak( "$class new() doesn't know to clone $new" );
     }
   } else { # misc stuff
-    $new = [ '', {}, @_ ];
+    $new = \@( '', \%(), @_ );
   }
 
   # By now it's a treelet:  [ 'foo', {}, ... ]
@@ -46,7 +46,7 @@ sub new {
     if(ref($x || '') eq 'ARRAY') {
       $x = $class->new($x); # recurse
     } elsif(ref($x || '') eq 'HASH') {
-      $x = { %$x };
+      $x = \%( %$x );
     }
      # otherwise leave it.
   }
