@@ -6,7 +6,7 @@ use strict;
 
 sub new {  # Class->new(text);
   my $class = shift;
-  return bless ['text', @_], ref($class) || $class;
+  return bless \@('text', @_), ref($class) || $class;
 }
 
 # Purely accessors:
