@@ -91,8 +91,8 @@ sub Complete {
     $r      = 0;
 
     $prompt = shift;
-    if (ref $_[0] || $_[0] =~ m/^\*/) {
-	@cmp_lst = sort @{$_[0]};
+    if (ref @_[0] || @_[0] =~ m/^\*/) {
+	@cmp_lst = sort @{@_[0]};
     }
     else {
 	@cmp_lst = sort(@_);
@@ -119,7 +119,7 @@ sub Complete {
                 # (TAB) attempt completion
                 $_ eq "\t" && do {
                     @match = grep(m/^\Q$return/, @cmp_lst);
-                    unless ($#match +< 0) {
+                    unless ((@match-1) +< 0) {
                         $l = length($test = shift(@match));
                         foreach $cmp (@match) {
                             until (substr($cmp, 0, $l) eq substr($test, 0, $l)) {
