@@ -231,7 +231,7 @@ sub CLEAR {
 package Tie::StdHash;
 # @ISA = qw(Tie::Hash);		# would inherit new() only
 
-sub TIEHASH  { bless {}, @_[0] }
+sub TIEHASH  { bless \%(), @_[0] }
 sub STORE    { @_[0]->{@_[1]} = @_[2] }
 sub FETCH    { @_[0]->{@_[1]} }
 sub FIRSTKEY { my $a = scalar keys %{@_[0]}; each %{@_[0]} }
@@ -243,7 +243,7 @@ sub SCALAR   { scalar %{@_[0]} }
 
 package Tie::ExtraHash;
 
-sub TIEHASH  { my $p = shift; bless [{}, @_], $p }
+sub TIEHASH  { my $p = shift; bless \@(\%(), @_), $p }
 sub STORE    { @_[0][0]{@_[1]} = @_[2] }
 sub FETCH    { @_[0][0]{@_[1]} }
 sub FIRSTKEY { my $a = scalar keys %{@_[0][0]}; each %{@_[0][0]} }
