@@ -23,8 +23,8 @@ BEGIN {
 
                    );
     %EXPORT_TAGS = (
-        FIELDS => [ grep(m/^\$pw_/, @EXPORT_OK), @EXPORT ],
-        ALL    => [ @EXPORT, @EXPORT_OK ],
+        FIELDS => \@( grep(m/^\$pw_/, @EXPORT_OK), @EXPORT ),
+        ALL    => \@( @EXPORT, @EXPORT_OK ),
     );
 }
 use vars grep m/^\$pw_/, @EXPORT_OK;
@@ -39,7 +39,7 @@ my $IE = "[INTERNAL ERROR]";
 sub import { goto &Exporter::import }
 
 use Class::Struct qw(struct);
-struct 'User::pwent' => [
+struct 'User::pwent' => \@(
     name    => '$',         # pwent[0]
     passwd  => '$',         # pwent[1]
     uid     => '$',         # pwent[2]
@@ -63,7 +63,7 @@ struct 'User::pwent' => [
     # you might not have this one
     expire  => '$',         # pwent[9]
 
-];
+);
 
 
 # init our groks hash to be true if the built platform knew how
