@@ -4,10 +4,10 @@ sub define {
     my %arg = @_;
     # warning: alwyas create a new hash; %^H is saved, and altering
     # values referenced by it, will have effect on it.
-    %^H{'compsub'} = {
-                        %{ %^H{'compsub'} || {} },
+    %^H{'compsub'} = \%(
+                        %{ %^H{'compsub'} || \%() },
                         %arg,
-                       };
+                       );
 }
 
 1;
