@@ -27,14 +27,14 @@ sub import {
     my $class = shift;
     return unless @_;			# Ignore 'use constant;'
     my $constants;
-    my $multiple  = ref $_[0];
+    my $multiple  = ref @_[0];
     my $pkg = caller;
     my $symtab;
 
     $symtab = \%{*{Symbol::fetch_glob($pkg . '::')}};
 
     if ( $multiple ) {
-	if (ref $_[0] ne 'HASH') {
+	if (ref @_[0] ne 'HASH') {
 	    die("Invalid reference type '".ref(shift)."' not 'HASH'");
 	}
 	$constants = shift;
@@ -48,11 +48,11 @@ sub import {
 	}
 
 	# Normal constant name
-	if ($name =~ m/^_?[^\W_0-9]\w*\z/ and !$forbidden{$name}) {
+	if ($name =~ m/^_?[^\W_0-9]\w*\z/ and !%forbidden{$name}) {
 	    # Everything is okay
 
 	# Name forced into main, but we're not in main. Fatal.
-	} elsif ($forced_into_main{$name} and $pkg ne 'main') {
+	} elsif (%forced_into_main{$name} and $pkg ne 'main') {
 	    die("Constant name '$name' is forced into main::");
 
 	# Starts with double underscore. Fatal.
@@ -63,9 +63,9 @@ sub import {
 	} elsif ($name =~ m/^[A-Za-z_]\w*\z/) {
 	    # Then we'll warn only if you've asked for warnings
 	    if (warnings::enabled()) {
-		if ($keywords{$name}) {
+		if (%keywords{$name}) {
 		    warnings::warn("Constant name '$name' is a Perl keyword");
-		} elsif ($forced_into_main{$name}) {
+		} elsif (%forced_into_main{$name}) {
 		    warnings::warn("Constant name '$name' is " .
 			"forced into package main::");
 		}
@@ -87,10 +87,10 @@ sub import {
 
 	{
 	    no strict 'refs';
-	    my $full_name = "${pkg}::$name";
-	    $declared{$full_name}++;
+	    my $full_name = "{$pkg}::$name";
+	    %declared{$full_name}++;
 	    if ($multiple || @_ == 1) {
-		my $scalar = $multiple ? $constants->{$name} : $_[0];
+		my $scalar = $multiple ? $constants->{$name} : @_[0];
                 *{Symbol::fetch_glob($full_name)} = sub () { $scalar };
 	    } elsif (@_) {
 		my @list = @_;
