@@ -250,7 +250,7 @@ sub unwrap {
 	  if (@$v) {
 	    $short = $sp . "0..@{$v}-1  " . 
 	      join(" ", 
-		   map {exists $v->[$_] ? stringify $v->[$_] : "empty"} ($[..$tArrayDepth)
+		   map {exists $v->[$_] ? stringify $v->[$_] : "empty"} (0..$tArrayDepth)
 		  ) . "$shortmore";
 	  } else {
 	    $short = $sp . "empty array";
@@ -261,7 +261,7 @@ sub unwrap {
 	#  print "$short\n";
 	#  return;
 	#}
-	for $num ($[ .. $tArrayDepth) {
+	for $num (0 .. $tArrayDepth) {
 	    return if $DB::signal;
 	    print "$sp$num  ";
 	    if (exists $v->[$num]) {
