@@ -34,7 +34,7 @@ sub import {
     # avoid possible typo warnings
     %{*{Symbol::fetch_glob("$package\::FIELDS")}} = () unless %{*{Symbol::fetch_glob("$package\::FIELDS")}};
     my $fields = \%{*{Symbol::fetch_glob("$package\::FIELDS")}};
-    my $fattr = (%attr{$package} ||= [1]);
+    my $fattr = (%attr{$package} ||= \@(1));
     my $next = @$fattr;
 
     # Quiet pseudo-hash deprecation warning for uses of fields::new.
@@ -108,7 +108,7 @@ sub new {
     my $class = shift;
     $class = ref $class if ref $class;
     require Hash::Util;
-    my $self = bless {}, $class;
+    my $self = bless \%(), $class;
 
     # The lock_keys() prototype won't work since we require Hash::Util :(
     &Hash::Util::lock_keys(\%$self, _accessible_keys($class));
