@@ -99,7 +99,7 @@ This limitation might be removed in a future version of perl.
 $filetest::hint_bits = 0x00400000; # HINT_FILETEST_ACCESS
 
 sub import {
-    if ( $_[1] eq 'access' ) {
+    if ( @_[1] eq 'access' ) {
 	$^H ^|^= $filetest::hint_bits;
     } else {
 	die "filetest: the only implemented subpragma is 'access'.\n";
@@ -107,7 +107,7 @@ sub import {
 }
 
 sub unimport {
-    if ( $_[1] eq 'access' ) {
+    if ( @_[1] eq 'access' ) {
 	$^H ^&^= ^~^$filetest::hint_bits;
     } else {
 	die "filetest: the only implemented subpragma is 'access'.\n";
