@@ -31,7 +31,7 @@ sub import {
     my @imports = @_;
     foreach my $sym (@imports) {
         no strict 'refs';
-	*{Symbol::fetch_glob("${callpack}::$sym")} = \&{*{Symbol::fetch_glob("${callpack}::$sym")}};
+	*{Symbol::fetch_glob("{$callpack}::$sym")} = \&{*{Symbol::fetch_glob("{$callpack}::$sym")}};
     }
 };
 
