@@ -737,24 +737,128 @@ Perl_magic_get(pTHX_ SV *sv, MAGIC *mg)
 
     switch (*mg->mg_ptr) {
     case '^':
-	switch (*remaining) {
-	case 'C':		/* ^C, ^CHILD_ERROR_NATIVE */
-	    if (remaining[1] == '\0') {
-		sv_setiv(sv, (IV)PL_minus_c);
-	    }
-	    else if (strEQ(remaining, "CHILD_ERROR_NATIVE")) {
-		sv_setiv(sv, (IV)STATUS_NATIVE);
-	    }
-	    break;
-	case 'D':		/* ^D */
-	    if (remaining[1] == '\0') {
-		sv_setiv(sv, (IV)(PL_debug & DEBUG_MASK));
-	    } else if (strEQ(remaining, "DIE_HOOK")) { /* $^DIE_HOOK */
+	if (remaining[1] != '\0') {
+	    switch (*remaining) {
+	    case 'C':
+		if (strEQ(remaining, "CHILD_ERROR_NATIVE")) { /* $^CHILD_ERROR_NATIVE */
+		    sv_setiv(sv, (IV)STATUS_NATIVE);
+		}
+		break;
+	    case 'D':
+		if (strEQ(remaining, "DIE_HOOK")) { /* $^DIE_HOOK */
+		    break;
+		}
+		break;
+	    case 'E':
+		if (strEQ(remaining, "EGID")) { /* $^EGID */
+		    sv_setiv(sv, (IV)PL_egid);
+		  add_groups:
+#ifdef HAS_GETGROUPS
+		    {
+			Groups_t *gary = NULL;
+			I32 i, num_groups = getgroups(0, gary);
+			Newx(gary, num_groups, Groups_t);
+			num_groups = getgroups(num_groups, gary);
+			for (i = 0; i < num_groups; i++)
+			    Perl_sv_catpvf(aTHX_ sv, " %"IVdf, (IV)gary[i]);
+			Safefree(gary);
+		    }
+		    (void)SvIOK_on(sv);	/* what a wonderful hack! */
+#endif
+		    break;
+		}
+		break;
+	    case 'G':
+		if (strEQ(remaining, "GID")) { /* $^GID */
+		    sv_setiv(sv, (IV)PL_gid);
+		    goto add_groups;
+		}
+		break;
+	    case 'M': /* $^MATCH */
+		if (strEQ(remaining, "MATCH")) {
+		    if (PL_curpm && (rx = PM_GETRE(PL_curpm))) {
+			/*
+			 * Pre-threads, this was paren = atoi(GvENAME((GV*)mg->mg_obj));
+			 * XXX Does the new way break anything?
+			 */
+			paren = atoi(mg->mg_ptr); /* $& is in [0] */
+			CALLREG_NUMBUF_FETCH(rx,paren,sv);
+			break;
+		    }
+		    sv_setsv(sv,&PL_sv_undef);
+		}
+		break;
+	    case 'O':
+		if (strEQ(remaining, "OPEN")) { /* $^OPEN */
+		    Perl_emulate_cop_io(aTHX_ &PL_compiling, sv);
+		}
+		break;
+	    case 'P':
+		if (strEQ(remaining, "PREMATCH")) { /* $^PREMATCH */
+		    goto do_prematch_fetch;
+		} else if (strEQ(remaining, "POSTMATCH")) { /* $^POSTMATCH */
+		    goto do_postmatch_fetch;
+		}
+		break;
+	    case 'T':
+		if (strEQ(remaining, "TAINT")) /* $^TAINT */
+		    sv_setiv(sv, PL_tainting
+			     ? (PL_taint_warn || PL_unsafe ? -1 : 1)
+			     : 0);
+		break;
+	    case 'U':		/* $^UNICODE, $^UTF8LOCALE, $^UTF8CACHE */
+		if (strEQ(remaining, "UNICODE"))
+		    sv_setuv(sv, (UV) PL_unicode);
+		else if (strEQ(remaining, "UTF8LOCALE"))
+		    sv_setuv(sv, (UV) PL_utf8locale);
+		else if (strEQ(remaining, "UTF8CACHE"))
+		    sv_setiv(sv, (IV) PL_utf8cache);
+		break;
+	    case 'W':
+		if (strEQ(remaining, "WARNING_BITS")) { /* $^WARNING_BITS */
+		    if (PL_compiling.cop_warnings == pWARN_NONE) {
+			sv_setpvn(sv, WARN_NONEstring, WARNsize) ;
+		    }
+		    else if (PL_compiling.cop_warnings == pWARN_STD) {
+			sv_setpvn(
+			    sv, 
+			    (PL_dowarn & G_WARN_ON) ? WARN_ALLstring : WARN_NONEstring,
+			    WARNsize
+			    );
+		    }
+		    else if (PL_compiling.cop_warnings == pWARN_ALL) {
+			/* Get the bit mask for $warnings::Bits{all}, because
+			 * it could have been extended by warnings::register */
+			HV * const bits=get_hv("warnings::Bits", FALSE);
+			if (bits) {
+			    SV ** const bits_all = hv_fetchs(bits, "all", FALSE);
+			    if (bits_all)
+				sv_setsv(sv, *bits_all);
+			}
+			else {
+			    sv_setpvn(sv, WARN_ALLstring, WARNsize) ;
+			}
+		    }
+		    else {
+			sv_setpvn(sv, (char *) (PL_compiling.cop_warnings + 1),
+				  *PL_compiling.cop_warnings);
+		    }
+		    SvPOK_only(sv);
+		} else if (strEQ(remaining, "WARN_HOOK")) { /* $^WARN_HOOK */
+		    break;
+		}
 		break;
 	    }
-	    break;
-	case 'E':  /* ^E */
-	    if (remaining[1] == '\0') {
+	}
+	else {
+	    switch (*remaining) {
+	    case 'C':		/* $^C */
+		sv_setiv(sv, (IV)PL_minus_c);
+		break;
+	    case 'D':		/* $^D */
+		sv_setiv(sv, (IV)(PL_debug & DEBUG_MASK));
+		break;
+	    case 'E':  /* $^E */
 #if defined(MACOS_TRADITIONAL)
 		{
 		    char msg[256];
@@ -808,126 +912,51 @@ Perl_magic_get(pTHX_ SV *sv, MAGIC *mg)
 #endif
 		SvRTRIM(sv);
 		SvNOK_on(sv);	/* what a wonderful hack! */
-	    }
-	    break;
-	case 'F':		/* ^F */
-	    sv_setiv(sv, (IV)PL_maxsysfd);
-	    break;
-	case 'H':		/* ^H */
-	    sv_setiv(sv, (IV)PL_hints);
-	    break;
-	case 'I':		/* ^I */
-	    sv_setpv(sv, PL_inplace); /* Will undefine sv if PL_inplace is NULL */
-	    break;
-	case 'O':		/* ^O & ^OPEN */
-	    if (remaining[1] == '\0') {
+		break;
+	    case 'F':		/* $^F */
+		sv_setiv(sv, (IV)PL_maxsysfd);
+		break;
+	    case 'H':		/* $^H */
+		sv_setiv(sv, (IV)PL_hints);
+		break;
+	    case 'I':		/* $^I */
+		sv_setpv(sv, PL_inplace); /* Will undefine sv if PL_inplace is NULL */
+		break;
+	    case 'O':		/* $^O */
 		sv_setpv(sv, PL_osname);
 		SvTAINTED_off(sv);
-	    }
-	    else if (strEQ(remaining, "OPEN")) {
-		Perl_emulate_cop_io(aTHX_ &PL_compiling, sv);
-	    }
-	    break;
-	case 'P':		
-	    if (remaining[1] == '\0') {       /* ^P */
+		break;
+	    case 'P':		/* $^P */
 		sv_setiv(sv, (IV)PL_perldb);
-	    } else if (strEQ(remaining, "PREMATCH")) { /* $^PREMATCH */
-		goto do_prematch_fetch;
-	    } else if (strEQ(remaining, "POSTMATCH")) { /* $^POSTMATCH */
-		goto do_postmatch_fetch;
-	    }
-	    break;
-	case 'S':		/* ^S */
-	    if (remaining[1] == '\0') {
+		break;
+	    case 'S':		/* $^S */
 		if (PL_parser && PL_parser->lex_state != LEX_NOTPARSING)
 		    SvOK_off(sv);
 		else if (PL_in_eval)
 		    sv_setiv(sv, PL_in_eval & ~(EVAL_INREQUIRE));
-	    else
-		sv_setiv(sv, 0);
-	}
-	break;
-	case 'T':		/* ^T */
-	    if (remaining[1] == '\0') {
-#ifdef BIG_TIME
-            sv_setnv(sv, PL_basetime);
-#else
-            sv_setiv(sv, (IV)PL_basetime);
-#endif
-        }
-	else if (strEQ(remaining, "TAINT"))
-            sv_setiv(sv, PL_tainting
-		    ? (PL_taint_warn || PL_unsafe ? -1 : 1)
-		    : 0);
-        break;
-	case 'U':		/* $^UNICODE, $^UTF8LOCALE, $^UTF8CACHE */
-	    if (strEQ(remaining, "UNICODE"))
-		sv_setuv(sv, (UV) PL_unicode);
-	    else if (strEQ(remaining, "UTF8LOCALE"))
-		sv_setuv(sv, (UV) PL_utf8locale);
-	    else if (strEQ(remaining, "UTF8CACHE"))
-		sv_setiv(sv, (IV) PL_utf8cache);
-	    break;
-	case 'W':		/* ^W  & $^WARNING_BITS */
-	    if (remaining[1] == '\0')
-		sv_setiv(sv, (IV)((PL_dowarn & G_WARN_ON) ? TRUE : FALSE));
-	    else if (strEQ(remaining, "WARNING_BITS")) {
-		if (PL_compiling.cop_warnings == pWARN_NONE) {
-		    sv_setpvn(sv, WARN_NONEstring, WARNsize) ;
-		}
-		else if (PL_compiling.cop_warnings == pWARN_STD) {
-		    sv_setpvn(
-			sv, 
-			(PL_dowarn & G_WARN_ON) ? WARN_ALLstring : WARN_NONEstring,
-			WARNsize
-			);
-		}
-		else if (PL_compiling.cop_warnings == pWARN_ALL) {
-		    /* Get the bit mask for $warnings::Bits{all}, because
-		     * it could have been extended by warnings::register */
-		    HV * const bits=get_hv("warnings::Bits", FALSE);
-		    if (bits) {
-			SV ** const bits_all = hv_fetchs(bits, "all", FALSE);
-			if (bits_all)
-			    sv_setsv(sv, *bits_all);
-		    }
-		    else {
-			sv_setpvn(sv, WARN_ALLstring, WARNsize) ;
-		    }
-		}
-		else {
-		    sv_setpvn(sv, (char *) (PL_compiling.cop_warnings + 1),
-			      *PL_compiling.cop_warnings);
-		}
-		SvPOK_only(sv);
-	    } else if (strEQ(remaining, "WARN_HOOK")) { /* $^WARN_HOOK */
+		else
+		    sv_setiv(sv, 0);
 		break;
-	    }
-	    break;
-	case 'M': /* $^MATCH */
-	    if (strEQ(remaining, "MATCH")) {
+	    case 'T':		/* $^T */
+#ifdef BIG_TIME
+		sv_setnv(sv, PL_basetime);
+#else
+		sv_setiv(sv, (IV)PL_basetime);
+#endif
+		break;
+	    case 'W':		/* $^W */
+		sv_setiv(sv, (IV)((PL_dowarn & G_WARN_ON) ? TRUE : FALSE));
+		break;
+	    case 'N':		/* ^N */
 		if (PL_curpm && (rx = PM_GETRE(PL_curpm))) {
-		    /*
-		     * Pre-threads, this was paren = atoi(GvENAME((GV*)mg->mg_obj));
-		     * XXX Does the new way break anything?
-		     */
-		    paren = atoi(mg->mg_ptr); /* $& is in [0] */
-		    CALLREG_NUMBUF_FETCH(rx,paren,sv);
-		    break;
+		    if (RX_LASTCLOSEPAREN(rx)) {
+			CALLREG_NUMBUF_FETCH(rx,RX_LASTCLOSEPAREN(rx),sv);
+			break;
+		    }
 		}
 		sv_setsv(sv,&PL_sv_undef);
+		break;
 	    }
-	    break;
-	case 'N':		/* ^N */
-	    if (PL_curpm && (rx = PM_GETRE(PL_curpm))) {
-		if (RX_LASTCLOSEPAREN(rx)) {
-		    CALLREG_NUMBUF_FETCH(rx,RX_LASTCLOSEPAREN(rx),sv);
-		    break;
-		}
-		
-	    }
-	    sv_setsv(sv,&PL_sv_undef);
-	    break;
 	}
 	break;
     case '1': case '2': case '3': case '4':
@@ -1022,25 +1051,6 @@ Perl_magic_get(pTHX_ SV *sv, MAGIC *mg)
     case '>':
 	sv_setiv(sv, (IV)PL_euid);
 	break;
-    case '(':
-	sv_setiv(sv, (IV)PL_gid);
-	goto add_groups;
-    case ')':
-	sv_setiv(sv, (IV)PL_egid);
-      add_groups:
-#ifdef HAS_GETGROUPS
-	{
-	    Groups_t *gary = NULL;
-	    I32 i, num_groups = getgroups(0, gary);
-            Newx(gary, num_groups, Groups_t);
-            num_groups = getgroups(num_groups, gary);
-	    for (i = 0; i < num_groups; i++)
-		Perl_sv_catpvf(aTHX_ sv, " %"IVdf, (IV)gary[i]);
-            Safefree(gary);
-	}
-	(void)SvIOK_on(sv);	/* what a wonderful hack! */
-#endif
-	break;
 #ifndef MACOS_TRADITIONAL
     case '0':
 	break;
@@ -2169,16 +2179,203 @@ Perl_magic_set(pTHX_ SV *sv, MAGIC *mg)
 
     switch (*mg->mg_ptr) {
     case '^':
-	switch (*remaining) {
-	case 'M': /* $^MATCH */
-	    if (strEQ(remaining, "MATCH"))
-		goto do_match;
-	case 'C':        /* ^C */
-	    PL_minus_c = (bool)SvIV(sv);
-	    break;
+	if (remaining[1] != '\0') {
+	    switch (*remaining) {
+	    case 'D':   /* $^DIE_HOOK */
+		if (strEQ(remaining, "DIE_HOOK")) {
+		    SvREFCNT_dec(PL_diehook);
+		    PL_diehook = newSVsv(sv);
+		}
+		break;
+	    case 'G':
+		if (strEQ(remaining, "GID")) { /* $^GID */
+		    PL_gid = SvIV(sv);
+		    if (PL_delaymagic) {
+			PL_delaymagic |= DM_RGID;
+			break;                              /* don't do magic till later */
+		    }
+#ifdef HAS_SETRGID
+		    (void)setrgid((Gid_t)PL_gid);
+#else
+#ifdef HAS_SETREGID
+		    (void)setregid((Gid_t)PL_gid, (Gid_t)-1);
+#else
+#ifdef HAS_SETRESGID
+		    (void)setresgid((Gid_t)PL_gid, (Gid_t)-1, (Gid_t) 1);
+#else
+		    if (PL_gid == PL_egid)                  /* special case $( = $) */
+			(void)PerlProc_setgid(PL_gid);
+		    else {
+			PL_gid = PerlProc_getgid();
+			Perl_croak(aTHX_ "setrgid() not implemented");
+		    }
+#endif
+#endif
+#endif
+		    PL_gid = PerlProc_getgid();
+		    PL_tainting |= (PL_uid && (PL_euid != PL_uid || PL_egid != PL_gid));
+		}
+		break;
+	    case 'E':
+		if (strEQ(remaining, "EGID")) {  /* $^EGID */
+#ifdef HAS_SETGROUPS
+		    const char *p = SvPV_const(sv, len);
+		    Groups_t *gary = NULL;
+
+		    while (isSPACE(*p))
+			++p;
+		    PL_egid = Atol(p);
+		    for (i = 0; i < NGROUPS; ++i) {
+			while (*p && !isSPACE(*p))
+			    ++p;
+			while (isSPACE(*p))
+			    ++p;
+			if (!*p)
+			    break;
+			if(!gary)
+			    Newx(gary, i + 1, Groups_t);
+			else
+			    Renew(gary, i + 1, Groups_t);
+			gary[i] = Atol(p);
+		    }
+		    if (i)
+			(void)setgroups(i, gary);
+		    Safefree(gary);
+#else  /* HAS_SETGROUPS */
+		    PL_egid = SvIV(sv);
+#endif /* HAS_SETGROUPS */
+		    if (PL_delaymagic) {
+			PL_delaymagic |= DM_EGID;
+			break;                              /* don't do magic till later */
+		    }
+#ifdef HAS_SETEGID
+		    (void)setegid((Gid_t)PL_egid);
+#else
+#ifdef HAS_SETREGID
+		    (void)setregid((Gid_t)-1, (Gid_t)PL_egid);
+#else
+#ifdef HAS_SETRESGID
+		    (void)setresgid((Gid_t)-1, (Gid_t)PL_egid, (Gid_t)-1);
+#else
+		    if (PL_egid == PL_gid)                  /* special case $) = $( */
+			(void)PerlProc_setgid(PL_egid);
+		    else {
+			PL_egid = PerlProc_getegid();
+			Perl_croak(aTHX_ "setegid() not implemented");
+		    }
+#endif
+#endif
+#endif
+		    PL_egid = PerlProc_getegid();
+		    PL_tainting |= (PL_uid && (PL_euid != PL_uid || PL_egid != PL_gid));
+		    break;
+		}
+		break;
+	    case 'M':   /* $^MATCH */
+		if (strEQ(remaining, "MATCH"))
+		    goto do_match;
+		break;
+	    case 'O':   /* $^OPEN */
+		if (strEQ(remaining, "OPEN")) {
+		    STRLEN len;
+		    const char *const start = SvPV(sv, len);
+		    const char *out = (const char*)memchr(start, '\0', len);
+		    SV *tmp;
+		    HV* old_cop_hints_hash;
+
+
+		    PL_compiling.cop_hints |= HINT_LEXICAL_IO_IN | HINT_LEXICAL_IO_OUT;
+		    PL_hints
+			|= HINT_LOCALIZE_HH | HINT_LEXICAL_IO_IN | HINT_LEXICAL_IO_OUT;
+
+		    /* Opening for input is more common than opening for output, so
+		       ensure that hints for input are sooner on linked list.  */
+
+		    old_cop_hints_hash = PL_compiling.cop_hints_hash;
+		    PL_compiling.cop_hints_hash = newHVhv(PL_compiling.cop_hints_hash);
+		    SvREFCNT_dec(old_cop_hints_hash);
+
+		    tmp = out ? newSVpvn_flags(out + 1, start + len - out - 1, 0) : newSVpvs_flags("", 0);
+		    (void)hv_store_ent(PL_compiling.cop_hints_hash, 
+				       newSVpvs_flags("open>", SVs_TEMP), tmp, 0);
+
+		    tmp = newSVpvn_flags(start, out ? (STRLEN)(out - start) : len, 0);
+		    (void)hv_store_ent(PL_compiling.cop_hints_hash,
+				       newSVpvs_flags("open<", SVs_TEMP), tmp, 0);
+		}
+		break;
+	    case 'P':
+		if (strEQ(remaining, "PREMATCH")) { /* $^PREMATCH */
+		    goto do_prematch;
+		} 
+		if (strEQ(remaining, "POSTMATCH")) { /* $^POSTMATCH */
+		    goto do_postmatch;
+		}
+		break;
+	    case 'U':        /* ^UTF8CACHE */
+		if (strEQ(remaining, "UTF8CACHE")) {
+		    PL_utf8cache = (signed char) sv_2iv(sv);
+		}
+		break;
+	    case 'W':
+		if (strEQ(remaining, "WARNING_BITS")) { /* $^WARNING_BITS */
+		    if ( ! (PL_dowarn & G_WARN_ALL_MASK)) {
+			if (!SvPOK(sv) && PL_localizing) {
+			    sv_setpvn(sv, WARN_NONEstring, WARNsize);
+			    PL_compiling.cop_warnings = pWARN_NONE;
+			    break;
+			}
+			{
+			    STRLEN len, i;
+			    int accumulate = 0 ;
+			    int any_fatals = 0 ;
+			    const char * const ptr = SvPV_const(sv, len) ;
+			    for (i = 0 ; i < len ; ++i) {
+				accumulate |= ptr[i] ;
+				any_fatals |= (ptr[i] & 0xAA) ;
+			    }
+			    if (!accumulate) {
+				if (!specialWARN(PL_compiling.cop_warnings))
+				    PerlMemShared_free(PL_compiling.cop_warnings);
+				PL_compiling.cop_warnings = pWARN_NONE;
+			    }
+			    /* Yuck. I can't see how to abstract this:  */
+			    else if (isWARN_on(((STRLEN *)SvPV_nolen_const(sv)) - 1,
+					       WARN_ALL) && !any_fatals) {
+				if (!specialWARN(PL_compiling.cop_warnings))
+				    PerlMemShared_free(PL_compiling.cop_warnings);
+				PL_compiling.cop_warnings = pWARN_ALL;
+				PL_dowarn |= G_WARN_ONCE ;
+			    }
+			    else {
+				STRLEN len;
+				const char *const p = SvPV_const(sv, len);
+				
+				PL_compiling.cop_warnings
+				    = Perl_new_warnings_bitfield(aTHX_ PL_compiling.cop_warnings,
+								 p, len);
+
+				if (isWARN_on(PL_compiling.cop_warnings, WARN_ONCE))
+				    PL_dowarn |= G_WARN_ONCE ;
+			    }
+			    
+			}
+		    }
+		}
+		else if (strEQ(remaining, "WARN_HOOK")) { /* $^WARN_HOOK */
+		    SvREFCNT_dec(PL_warnhook);
+		    PL_warnhook = newSVsv(sv);
+		}
+		break;
+	    }
+	}
+	else {
+	    switch (*remaining) {
+	    case 'C':        /* ^C */
+		PL_minus_c = (bool)SvIV(sv);
+		break;
 	    
-	case 'D':        /* ^D */
-	    if (remaining[1] == '\0') {
+	    case 'D':        /* ^D */
 #ifdef DEBUGGING
 		s = SvPV_nolen_const(sv);
 		PL_debug = get_debug_opts(&s, 0) | DEBUG_TOP_FLAG;
@@ -2186,14 +2383,9 @@ Perl_magic_set(pTHX_ SV *sv, MAGIC *mg)
 #else
 		PL_debug = (SvIV(sv)) | DEBUG_TOP_FLAG;
 #endif
-	    }
-	    else if (strEQ(remaining, "DIE_HOOK")) {
-		SvREFCNT_dec(PL_diehook);
-		PL_diehook = newSVsv(sv);
-	    }
-	    break;
-	case 'E':  /* ^E */
-	    if (remaining[1] == '\0') {
+		break;
+
+	    case 'E':  /* ^E */
 #ifdef MACOS_TRADITIONAL
 		gMacPerl_OSErr = SvIV(sv);
 #else
@@ -2212,135 +2404,44 @@ Perl_magic_set(pTHX_ SV *sv, MAGIC *mg)
 #    endif
 #  endif
 #endif
-	    }
-	    break;
-	case 'F':        /* ^F */
-	    PL_maxsysfd = SvIV(sv);
-	    break;
-	case 'H':        /* ^H */
-	    PL_hints = SvIV(sv);
-	    break;
-	case 'I':        /* ^I */ /* NOT \t in EBCDIC */
-	    Safefree(PL_inplace);
-	    PL_inplace = SvOK(sv) ? savesvpv(sv) : NULL;
-	    break;
-	case 'O':        /* ^O */
-	    if (remaining[1] == '\0') {
+		break;
+	    case 'F':        /* ^F */
+		PL_maxsysfd = SvIV(sv);
+		break;
+	    case 'H':        /* ^H */
+		PL_hints = SvIV(sv);
+		break;
+	    case 'I':        /* ^I */ /* NOT \t in EBCDIC */
+		Safefree(PL_inplace);
+		PL_inplace = SvOK(sv) ? savesvpv(sv) : NULL;
+		break;
+	    case 'O':        /* ^O */
 		Safefree(PL_osname);
 		PL_osname = NULL;
 		if (SvOK(sv)) {
 		    TAINT_PROPER("assigning to $^O");
 		    PL_osname = savesvpv(sv);
 		}
-	    }
-	    else if (strEQ(remaining, "OPEN")) {
-		STRLEN len;
-		const char *const start = SvPV(sv, len);
-		const char *out = (const char*)memchr(start, '\0', len);
-		SV *tmp;
-		HV* old_cop_hints_hash;
-
-
-		PL_compiling.cop_hints |= HINT_LEXICAL_IO_IN | HINT_LEXICAL_IO_OUT;
-		PL_hints
-		    |= HINT_LOCALIZE_HH | HINT_LEXICAL_IO_IN | HINT_LEXICAL_IO_OUT;
-
-		/* Opening for input is more common than opening for output, so
-		   ensure that hints for input are sooner on linked list.  */
-
-		old_cop_hints_hash = PL_compiling.cop_hints_hash;
-		PL_compiling.cop_hints_hash = newHVhv(PL_compiling.cop_hints_hash);
-		SvREFCNT_dec(old_cop_hints_hash);
-
-		tmp = out ? newSVpvn_flags(out + 1, start + len - out - 1, 0) : newSVpvs_flags("", 0);
-		(void)hv_store_ent(PL_compiling.cop_hints_hash, 
-				   newSVpvs_flags("open>", SVs_TEMP), tmp, 0);
-
-		tmp = newSVpvn_flags(start, out ? (STRLEN)(out - start) : len, 0);
-		(void)hv_store_ent(PL_compiling.cop_hints_hash,
-				   newSVpvs_flags("open<", SVs_TEMP), tmp, 0);
-	    }
-	    break;
-	case 'P':        /* ^P */
-	    if (remaining[1] == '\0') { /* ^P */
+		break;
+	    case 'P':        /* ^P */
 		PL_perldb = SvIV(sv);
 		if (PL_perldb && !PL_DBsingle)
 		    init_debugger();
 		break;
-	    } else if (strEQ(remaining, "PREMATCH")) { /* $^PREMATCH */
-		goto do_prematch;
-	    } else if (strEQ(remaining, "POSTMATCH")) { /* $^POSTMATCH */
-		goto do_postmatch;
-	    }
-	case 'T':        /* ^T */
+	    case 'T':        /* ^T */
 #ifdef BIG_TIME
-	    PL_basetime = (Time_t)(SvNOK(sv) ? SvNVX(sv) : sv_2nv(sv));
+		PL_basetime = (Time_t)(SvNOK(sv) ? SvNVX(sv) : sv_2nv(sv));
 #else
-	    PL_basetime = (Time_t)SvIV(sv);
+		PL_basetime = (Time_t)SvIV(sv);
 #endif
-	    break;
-	case 'U':        /* ^UTF8CACHE */
-	    if (strEQ(remaining, "UTF8CACHE")) {
-		PL_utf8cache = (signed char) sv_2iv(sv);
-	    }
-	    break;
-	case 'W':        /* ^W & $^WARNING_BITS */
-	    if (remaining[1] == '\0') {
+		break;
+	    case 'W':        /* ^W */
 		if ( ! (PL_dowarn & G_WARN_ALL_MASK)) {
 		    i = SvIV(sv);
 		    PL_dowarn = (PL_dowarn & ~G_WARN_ON)
 			| (i ? G_WARN_ON : G_WARN_OFF) ;
 		}
 	    }
-	    else if (strEQ(remaining, "WARNING_BITS")) {
-		if ( ! (PL_dowarn & G_WARN_ALL_MASK)) {
-		    if (!SvPOK(sv) && PL_localizing) {
-			sv_setpvn(sv, WARN_NONEstring, WARNsize);
-			PL_compiling.cop_warnings = pWARN_NONE;
-			break;
-		    }
-		    {
-			STRLEN len, i;
-			int accumulate = 0 ;
-			int any_fatals = 0 ;
-			const char * const ptr = SvPV_const(sv, len) ;
-			for (i = 0 ; i < len ; ++i) {
-			    accumulate |= ptr[i] ;
-			    any_fatals |= (ptr[i] & 0xAA) ;
-			}
-			if (!accumulate) {
-			    if (!specialWARN(PL_compiling.cop_warnings))
-				PerlMemShared_free(PL_compiling.cop_warnings);
-			    PL_compiling.cop_warnings = pWARN_NONE;
-			}
-			/* Yuck. I can't see how to abstract this:  */
-			else if (isWARN_on(((STRLEN *)SvPV_nolen_const(sv)) - 1,
-					   WARN_ALL) && !any_fatals) {
-			    if (!specialWARN(PL_compiling.cop_warnings))
-				PerlMemShared_free(PL_compiling.cop_warnings);
-			    PL_compiling.cop_warnings = pWARN_ALL;
-			    PL_dowarn |= G_WARN_ONCE ;
-			}
-			else {
-			    STRLEN len;
-			    const char *const p = SvPV_const(sv, len);
-
-			    PL_compiling.cop_warnings
-				= Perl_new_warnings_bitfield(aTHX_ PL_compiling.cop_warnings,
-							     p, len);
-
-			    if (isWARN_on(PL_compiling.cop_warnings, WARN_ONCE))
-				PL_dowarn |= G_WARN_ONCE ;
-			}
-
-		    }
-		}
-	    }
-	    else if (strEQ(remaining, "WARN_HOOK")) { /* $^WARN_HOOK */
-		SvREFCNT_dec(PL_warnhook);
-		PL_warnhook = newSVsv(sv);
-	    }
-	    break;
 	}
 	break;
     case '`': /* $^PREMATCH caught below */
@@ -2504,87 +2605,6 @@ Perl_magic_set(pTHX_ SV *sv, MAGIC *mg)
         PL_euid = PerlProc_geteuid();
         PL_tainting |= (PL_uid && (PL_euid != PL_uid || PL_egid != PL_gid));
         break;
-    case '(':
-        PL_gid = SvIV(sv);
-        if (PL_delaymagic) {
-            PL_delaymagic |= DM_RGID;
-            break;                              /* don't do magic till later */
-        }
-#ifdef HAS_SETRGID
-        (void)setrgid((Gid_t)PL_gid);
-#else
-#ifdef HAS_SETREGID
-        (void)setregid((Gid_t)PL_gid, (Gid_t)-1);
-#else
-#ifdef HAS_SETRESGID
-      (void)setresgid((Gid_t)PL_gid, (Gid_t)-1, (Gid_t) 1);
-#else
-        if (PL_gid == PL_egid)                  /* special case $( = $) */
-            (void)PerlProc_setgid(PL_gid);
-        else {
-            PL_gid = PerlProc_getgid();
-            Perl_croak(aTHX_ "setrgid() not implemented");
-        }
-#endif
-#endif
-#endif
-        PL_gid = PerlProc_getgid();
-        PL_tainting |= (PL_uid && (PL_euid != PL_uid || PL_egid != PL_gid));
-        break;
-    case ')':
-#ifdef HAS_SETGROUPS
-        {
-            const char *p = SvPV_const(sv, len);
-            Groups_t *gary = NULL;
-
-            while (isSPACE(*p))
-                ++p;
-            PL_egid = Atol(p);
-            for (i = 0; i < NGROUPS; ++i) {
-                while (*p && !isSPACE(*p))
-                    ++p;
-                while (isSPACE(*p))
-                    ++p;
-                if (!*p)
-                    break;
-                if(!gary)
-                    Newx(gary, i + 1, Groups_t);
-                else
-                    Renew(gary, i + 1, Groups_t);
-                gary[i] = Atol(p);
-            }
-            if (i)
-                (void)setgroups(i, gary);
-            Safefree(gary);
-        }
-#else  /* HAS_SETGROUPS */
-        PL_egid = SvIV(sv);
-#endif /* HAS_SETGROUPS */
-        if (PL_delaymagic) {
-            PL_delaymagic |= DM_EGID;
-            break;                              /* don't do magic till later */
-        }
-#ifdef HAS_SETEGID
-        (void)setegid((Gid_t)PL_egid);
-#else
-#ifdef HAS_SETREGID
-        (void)setregid((Gid_t)-1, (Gid_t)PL_egid);
-#else
-#ifdef HAS_SETRESGID
-        (void)setresgid((Gid_t)-1, (Gid_t)PL_egid, (Gid_t)-1);
-#else
-        if (PL_egid == PL_gid)                  /* special case $) = $( */
-            (void)PerlProc_setgid(PL_egid);
-        else {
-            PL_egid = PerlProc_getegid();
-            Perl_croak(aTHX_ "setegid() not implemented");
-        }
-#endif
-#endif
-#endif
-        PL_egid = PerlProc_getegid();
-        PL_tainting |= (PL_uid && (PL_euid != PL_uid || PL_egid != PL_gid));
-        break;
     case ':':
         PL_chopset = SvPV_force(sv,len);
         break;
