@@ -45,50 +45,50 @@ my %alias;
 
 # Format is "this function" => "does these op names"
 my @raw_alias = (
-		 Perl_do_kv => [qw( keys values )],
-		 Perl_unimplemented_op => [qw(padany mapstart custom)],
+		 Perl_do_kv => \@(qw( keys values )),
+		 Perl_unimplemented_op => \@(qw(padany mapstart custom)),
 		 # All the ops with a body of { return NORMAL; }
-		 Perl_pp_null => [qw(scalar regcmaybe lineseq scope)],
+		 Perl_pp_null => \@(qw(scalar regcmaybe lineseq scope)),
 
-		 Perl_pp_goto => ['dump'],
-		 Perl_pp_require => ['dofile'],
-		 Perl_pp_sysread => [qw(read recv)],
-		 Perl_pp_sysseek => ['seek'],
-		 Perl_pp_ioctl => ['fcntl'],
-		 Perl_pp_ssockopt => ['gsockopt'],
-		 Perl_pp_getpeername => ['getsockname'],
-		 Perl_pp_stat => ['lstat'],
-		 Perl_pp_ftrowned => [qw(fteowned ftzero ftsock ftchr ftblk
+		 Perl_pp_goto => \@('dump'),
+		 Perl_pp_require => \@('dofile'),
+		 Perl_pp_sysread => \@(qw(read recv)),
+		 Perl_pp_sysseek => \@('seek'),
+		 Perl_pp_ioctl => \@('fcntl'),
+		 Perl_pp_ssockopt => \@('gsockopt'),
+		 Perl_pp_getpeername => \@('getsockname'),
+		 Perl_pp_stat => \@('lstat'),
+		 Perl_pp_ftrowned => \@(qw(fteowned ftzero ftsock ftchr ftblk
 					 ftfile ftdir ftpipe ftsuid ftsgid
- 					 ftsvtx)],
-		 Perl_pp_fttext => ['ftbinary'],
-		 Perl_pp_gmtime => ['localtime'],
-		 Perl_pp_semget => [qw(shmget msgget)],
-		 Perl_pp_semctl => [qw(shmctl msgctl)],
-		 Perl_pp_ghostent => [qw(ghbyname ghbyaddr)],
-		 Perl_pp_gnetent => [qw(gnbyname gnbyaddr)],
-		 Perl_pp_gprotoent => [qw(gpbyname gpbynumber)],
-		 Perl_pp_gservent => [qw(gsbyname gsbyport)],
-		 Perl_pp_gpwent => [qw(gpwnam gpwuid)],
-		 Perl_pp_ggrent => [qw(ggrnam ggrgid)],
-		 Perl_pp_ftis => [qw(ftsize ftmtime ftatime ftctime)],
-		 Perl_pp_chown => [qw(unlink chmod utime kill)],
-		 Perl_pp_link => ['symlink'],
-		 Perl_pp_ftrread => [qw(ftrwrite ftrexec fteread ftewrite
- 					fteexec)],
-		 Perl_pp_shmwrite => [qw(shmread msgsnd msgrcv semop)],
-		 Perl_pp_send => ['syswrite'],
-		 Perl_pp_defined => [qw(dor dorassign)],
-                 Perl_pp_and => ['andassign'],
-		 Perl_pp_or => ['orassign'],
-		 Perl_pp_ucfirst => ['lcfirst'],
-		 Perl_pp_sle => [qw(slt sgt sge)],
-		 Perl_pp_index => ['rindex'],
-		 Perl_pp_oct => ['hex'],
-		 Perl_pp_shift => ['pop'],
-		 Perl_pp_sin => [qw(cos exp log sqrt)],
-		 Perl_pp_bit_or => ['bit_xor'],
-		 Perl_pp_rv2av => ['rv2hv'],
+ 					 ftsvtx)),
+		 Perl_pp_fttext => \@('ftbinary'),
+		 Perl_pp_gmtime => \@('localtime'),
+		 Perl_pp_semget => \@(qw(shmget msgget)),
+		 Perl_pp_semctl => \@(qw(shmctl msgctl)),
+		 Perl_pp_ghostent => \@(qw(ghbyname ghbyaddr)),
+		 Perl_pp_gnetent => \@(qw(gnbyname gnbyaddr)),
+		 Perl_pp_gprotoent => \@(qw(gpbyname gpbynumber)),
+		 Perl_pp_gservent => \@(qw(gsbyname gsbyport)),
+		 Perl_pp_gpwent => \@(qw(gpwnam gpwuid)),
+		 Perl_pp_ggrent => \@(qw(ggrnam ggrgid)),
+		 Perl_pp_ftis => \@(qw(ftsize ftmtime ftatime ftctime)),
+		 Perl_pp_chown => \@(qw(unlink chmod utime kill)),
+		 Perl_pp_link => \@('symlink'),
+		 Perl_pp_ftrread => \@(qw(ftrwrite ftrexec fteread ftewrite
+ 					fteexec)),
+		 Perl_pp_shmwrite => \@(qw(shmread msgsnd msgrcv semop)),
+		 Perl_pp_send => \@('syswrite'),
+		 Perl_pp_defined => \@(qw(dor dorassign)),
+                 Perl_pp_and => \@('andassign'),
+		 Perl_pp_or => \@('orassign'),
+		 Perl_pp_ucfirst => \@('lcfirst'),
+		 Perl_pp_sle => \@(qw(slt sgt sge)),
+		 Perl_pp_index => \@('rindex'),
+		 Perl_pp_oct => \@('hex'),
+		 Perl_pp_shift => \@('pop'),
+		 Perl_pp_sin => \@(qw(cos exp log sqrt)),
+		 Perl_pp_bit_or => \@('bit_xor'),
+		 Perl_pp_rv2av => \@('rv2hv'),
 		);
 
 while (my ($func, $names) = splice @raw_alias, 0, 2) {
@@ -799,8 +799,8 @@ join		join or string		ck_fun		mst@	S L
 
 list		list			ck_null		m@	L
 lslice		list slice		ck_null		2	H L L
-anonlist	anonymous list ([])	ck_fun		ms@	L
-anonhash	anonymous hash ({})	ck_fun		ms@	L
+anonlist	anonymous list (%())	ck_fun		m@	L
+anonhash	anonymous hash (@())	ck_fun		m@	L
 
 splice		splice			ck_fun		m@	A S? S? L
 push		push			ck_fun		imsT@	A L
