@@ -715,10 +715,6 @@ Perl_leave_scope(pTHX_ I32 base)
 	    av = (AV*)gv; /* what to refcnt_dec */
 	restore_sv:
 	    sv = *(SV**)ptr;
-	    DEBUG_S(PerlIO_printf(Perl_debug_log,
-				  "restore svref: %p %p:%s -> %p:%s\n",
-				  (void*)ptr, (void*)sv, SvPEEK(sv),
-				  (void*)value, SvPEEK(value)));
 	    *(SV**)ptr = value;
 	    SvREFCNT_dec(sv);
 	    PL_localizing = 2;
