@@ -35,8 +35,8 @@ printf "Current package is: \%s\n", __PACKAGE__ unless "@ARGV" =~ m/PREREQ/;
 WriteMakefile(
     NAME          => 'Big::Dummy',
     VERSION_FROM  => 'lib/Big/Dummy.pm',
-    EXE_FILES     => [qw(bin/program)],
-    PREREQ_PM     => { strict => 0 },
+    EXE_FILES     => \@(qw(bin/program)),
+    PREREQ_PM     => \%( strict => 0 ),
     ABSTRACT_FROM => 'lib/Big/Dummy.pm',
     AUTHOR        => 'Michael G Schwern <schwern@pobox.com>',
 );
