@@ -73,7 +73,7 @@ sub run
             like $@->{description}, mkEvalErr("^$name Not Available: File opened only for output");
         }
 
-        eval ' $gz->write({})' ;
+        eval ' $gz->write(\%())' ;
 like $@->{description}, mkEvalErr("^{$CompressClass}::write: not a scalar reference");
 #like $@, mkEvalErr("^${CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref");
 
@@ -1369,12 +1369,12 @@ foreach my $file (0, 1)
     #ok ! -e $name1, "  File $name1 does not exist";
 
     my @data = (
-        [ '{ }',         "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ], 
-        [ '[ { } ]',     "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ], 
-        [ '[ [ { } ] ]', "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ], 
-        [ '[ "" ]',      "{$CompressClass}::write: input filename is undef or null string" ], 
-        [ '[ undef ]',   "{$CompressClass}::write: input filename is undef or null string" ], 
-        [ '[ \$Answer ]',"{$CompressClass}::write: input and output buffer are identical" ], 
+        \@( '\%()',         "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ), 
+        \@( '\@( \%() )',     "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ), 
+        \@( '\@( \@( \%() ) )', "{$CompressClass}::write: input parameter not a filename, filehandle, array ref or scalar ref" ), 
+        \@( '\@( "" )',      "{$CompressClass}::write: input filename is undef or null string" ), 
+        \@( '\@( undef )',   "{$CompressClass}::write: input filename is undef or null string" ), 
+        \@( '\@( \$Answer )',"{$CompressClass}::write: input and output buffer are identical" ), 
         #[ "not readable", 'xx' ], 
         # same filehandle twice, 'xx'
        ) ;
